Data Input
==========

.. toctree::
   :maxdepth: 1

   ../jupyter_notebooks/read_furuno_data.ipynb
   Furuno xarray backend (wradlib) <https://docs.wradlib.org/en/stable/notebooks/fileio/wradlib_furuno_backend.html>